@@ -2,6 +2,7 @@
 
 package HTTP::Engine::Interface::Test::ResponseWriter;
 use Moose;
+use HTTP::Engine::ResponseFinalizer;
 
 with qw(HTTP::Engine::Role::ResponseWriter);
 
@@ -11,10 +12,10 @@ has '_response' => (
 );
 
 sub finalize {
-    my ( $self, $c ) = @_;
+    my ( $self, $req, $res ) = @_;
 
-    $c->res->finalize($c);
-    $self->_response($c->res->as_http_response);
+    HTTP::Engine::ResponseFinalizer->finalize($req => $res);
+    $self->_response($res->as_http_response);
 }
 
 sub get_response {
