@@ -1,5 +1,3 @@
-#!/usr/bin/perl
-
 package HTTP::Engine::Role::RequestBuilder::Standard;
 use Moose::Role;
 
@@ -11,8 +9,6 @@ sub _build_cookies {
     my($self, $req) = @_;
 
     if (my $header = $req->header('Cookie')) {
-        #warn "headeR: $header";
-        #warn "headers: @{[ $c->req->header('Cookie') ]}";
         return { CGI::Simple::Cookie->parse($header) };
     } else {
         return {};
@@ -40,6 +36,8 @@ HTTP::Engine::Role::RequestBuilder::Standard -
 
 =head1 DESCRIPTION
 
+    INTERNAL USE ONLY
+
 =cut
 
 
